@@ -5,8 +5,8 @@
 
 #import <Foundation/Foundation.h>
 
-#import "RCTBridgeModule.h"
-#import "RCTViewManager.h"
+#import "React/RCTBridgeModule.h"
+#import "React/RCTViewManager.h"
 
 @interface RCT_EXTERN_MODULE(RNVideoProcessingManager, RCTViewManager)
 
